==> kelvin_sdk-6.0.0-py3-none-any.whl: kelvin/sdk/lib/utils/exception_utils.py <==
import json

from keycloak.exceptions import KeycloakError

from kelvin.sdk.client.error import APIError


def retrieve_error_message_from_api_exception(api_error: APIError) -> str:
    """
    Returns the 'pretty' error message from the APIError.

    :param api_error: The exception yielded by the service call.

    :return: a string containing the error message of the APIError.

    """
    try:
        message: str = ""
        api_errors = api_error.errors

        for error in api_errors:
            if error.http_status_code and error.http_status_code == 403:
                no_permission_error_message: str = """\n
                    You don’t have the required permissions to execute this command.\n
                    Please contact your system administrator. \n
                """
                return no_permission_error_message
            error_message = error.message
            if isinstance(error_message, list):
                converted_error_message = " ".join(item for item in error_message)
            else:
                converted_error_message = str(message)
            message = converted_error_message

        return f"(API error) {message}"

    except Exception as exc:
        return f"Error retrieving APIError: {str(exc)}"


def retrieve_error_message_from_keycloak_exception(keycloak_exception: KeycloakError) -> str:
    """
    Returns the 'pretty' error message from the KeycloakError.

    :param keycloak_exception: The exception yielded by the service call.

    :return: a string containing the error message of the KeycloakError.

    """
    try:
        try:
            message = json.loads(keycloak_exception.error_message)
        except (UnicodeDecodeError, AttributeError):
            message = {"error_description": "Error retrieving KeyCloak exception"}

        return f"(Authentication API error) {message.get('error_description')}"

    except Exception as exc:
        return f"Error handling KeycloakError exception: {str(exc)}"

==> kelvin_sdk-7.0.1-py3-none-any.whl: kelvin/sdk/lib/utils/exception_utils.py <==
import json

from keycloak.exceptions import KeycloakError

from kelvin.sdk.client.error import APIError


def retrieve_error_message_from_api_exception(api_error: APIError) -> str:
    """Returns the 'pretty' error message from the APIError.

    Parameters
    ----------
    api_error : APIError
         The exception yielded by the service call.

    Returns
    -------
    str:
        a string containing the error message of the APIError.

    """
    try:
        message: str = ""
        api_errors = api_error.errors

        for error in api_errors:
            if error.http_status_code and error.http_status_code == 403:
                no_permission_error_message: str = """\n
                    You don’t have the required permissions to execute this command.\n
                    Please contact your system administrator. \n
                """
                return no_permission_error_message
            error_message = error.message
            if isinstance(error_message, list):
                converted_error_message = " ".join(item for item in error_message)
            else:
                converted_error_message = str(message)
            message = converted_error_message

        return f"(API error) {message}"

    except Exception as exc:
        return f"Error retrieving APIError - {str(exc)}"


def retrieve_error_message_from_keycloak_exception(keycloak_exception: KeycloakError) -> str:
    """Returns the 'pretty' error message from the KeycloakError.

    Parameters
    ----------
    keycloak_exception : KeycloakError
        The exception yielded by the service call.

    Returns
    -------
    str:
        a string containing the error message of the KeycloakError.

    """
    try:
        try:
            message = json.loads(keycloak_exception.error_message)
        except (UnicodeDecodeError, AttributeError):
            message = {"error_description": "Error retrieving KeyCloak exception"}

        return f"(Authentication API error) {message.get('error_description')}"

    except Exception as exc:
        return f"Error handling KeycloakError exception - {str(exc)}"
